#
# spec file for package compiz-plugins-main
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _rev    9a0178324a73e286352b00c66f02cc07
Name:           compiz-plugins-main
Version:        0.8.18
Release:        bp154.1.67
Summary:        OpenGL window and compositing manager plugins
License:        GPL-2.0-or-later
URL:            https://gitlab.com/compiz/compiz-plugins-main
Source:         https://gitlab.com/compiz/compiz-plugins-main/uploads/%{_rev}/%{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  libjpeg8-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bcop) >= 0.7.3
BuildRequires:  pkgconfig(cairo) >= 1.0
BuildRequires:  pkgconfig(cairo-xlib-xrender)
BuildRequires:  pkgconfig(compiz) < 0.9
BuildRequires:  pkgconfig(compiz-scale) < 0.9
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(pangocairo)
Requires:       compiz-plugins < 0.9
Conflicts:      compiz-extra < %{version}
ExcludeArch:    s390 s390x

%description
This package contains the non-default Compiz compositing manager
plugins.

%lang_package

%package devel
Summary:        OpenGL window and compositing manager plugins
Requires:       %{name} = %{version}
Requires:       pkgconfig(bcop)
Requires:       pkgconfig(cairo)
Requires:       pkgconfig(cairo-xlib-xrender)
Requires:       pkgconfig(compiz) < 0.9
Requires:       pkgconfig(compiz-scale) < 0.9
Requires:       pkgconfig(gl)
Requires:       pkgconfig(pangocairo)
Provides:       compiz-fusion-plugins-main-devel = %{version}
Obsoletes:      compiz-fusion-plugins-main-devel < %{version}

%description devel
This package contains the non-default Compiz compositing manager
plugins.

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%files
%license COPYING
%doc NEWS README.md
%{_libdir}/compiz/*
%{_datadir}/compiz/*

%files lang -f %{name}.lang

%files devel
%{_includedir}/compiz/
%{_libdir}/pkgconfig/*.pc

%changelog
* Sat Apr  4 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.8.18:
  * mousepoll: Also consider mouse clicks for its tracking delays.
  * Add an icon to the focuspoll plugin.
  * Make shortcuts to work with XInput2 for ezoom, neg and
    colorfilter.
  * focuspoll: Set org.a11y.Status.IsEnabled to true at startup to
    ensure applications like Firefox will be opened with
    accessibility support enabled.
  * titleinfo: Don't flag remote windows as root-owned.
  * ezoom/focuspoll: Greatly improve the focus tracking feature.
  * colorfilter: Add an option to enable filtering at startup.
  * colorfilter: Add an option to enable/disable cumulative filter
    mode.
  * colorfilter: Add support for showing a notification on filter
    change.
  * neg: Add an option to negate the window decoration too.
  * colorfilter: Add a negate filter, by inverting lightness in HSL
    representation.
  * Fix compilation with gcc-10.
  * Update translations.
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Drop support for old openSUSE versions.
* Sun Nov 11 2018 sor.alexei@meowr.ru
- Update to version 0.8.16:
  * Negative plugin improvements.
  * Add Ezoom plugin AT-SPI support.
  * Import icons from CCSM.
- Remove compiz-plugins-main-better-neg.patch: fixed upstream.
- Add a licence file to the package.
* Wed May  3 2017 sor.alexei@meowr.ru
- Add compiz-plugins-main-better-neg.patch: neg plugin improvements
  (commits 10c31d4, 2265ce0, 5e40455).
* Tue Apr 18 2017 sor.alexei@meowr.ru
- Update to version 0.8.14:
  * Improve Static Switcher.
  * Add more colorfilters.
  * Update Catalan translation.
- Workaround /usr/@DATADIRNAME@/locale/ on openSUSE Leap 42.1 and
  older.
* Sun Apr 10 2016 sor.alexei@meowr.ru
- Update to version 0.8.12.2:
  * Drop glib-gettext dependency.
    This fixes usage of autogen.sh with newer glib.
* Tue Mar  1 2016 sor.alexei@meowr.ru
- Update to 0.8.12.1:
  * Fix a crash in plugins on configurations with older gcc that
    depend on animation plugin. Note that plugins have to rebuild
    against fixed version for a fix to take effect.
  * Minor fixes.
- Remove compiz-fusion-plugins-main-bnc511578.patch: merged
  upstream.
* Sat Feb 13 2016 sor.alexei@meowr.ru
- Update to 0.8.12:
  * Add font family configuration in Resize info, Ring switcher,
    Scale addon, Shift switcher, and Thumbnail plugins.
  * Resize info plugin:
  - Do not ignore gradient colours 2 and 3 in Resize info plugin.
  - Border for size info was fixed with white instead of being
    some other colour the user might like better.
  - Enable 'always_show' option by default.
  * Change minimum and default amount of waves to 0 for Magic Lamp.
  * Move Desktop Wall plugin to compiz-core project.
- Remove compiz-fusion-plugins-main-defaults.patch:
  Desktop Wall has been moved to compiz-core.
- Exclude s390 and s390x architectures.
* Sat Dec 19 2015 sor.alexei@meowr.ru
- Use a better upstream tarball.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.8.9.
- Update dependencies.
- Change group to "System/GUI/Other".
* Fri May 16 2014 ku.b@gmx.de
- fix Group of devel package
- remove %%{buildroot} from build section
- remove outcommented and unused cmake build commands
- remove old compiz-fusion-plugins-main-devel obsoletes and provides
- run spec-cleaner over spec file
* Thu May 31 2012 robertherb@arcor.de
- use correct license format
* Thu Apr 28 2011 robertherb@arcor.de
- Update to version 0.8.8
* Tue Mar 30 2010 dimstar@opensuse.org
- Update to version 0.8.6:
  + Bug fix release
  + Keep version in sync with compiz.
* Wed Dec  9 2009 dimstar@opensuse.org
- Fix obsoletion of compiz-fusion-plugins-main (syntax error).
- Do not self-obsolete, fixes a rpmlint warning.
* Mon Nov 23 2009 dimstar@opensuse.org
- Provide / Obsolete also compiz-fusion-plugins-main-devel package.
* Mon Nov 16 2009 dimstar@opensuse.org
- Update to 0.8.4
- Rename package to compiz-plugins-main to follow upstream naming
- Drop NOMAD and workarounds-any-super-key-shows-main-menu.diff
- clean spec-file using spec-cleaner.
* Sun Oct  4 2009 aj@suse.de
- compiz-kde only exists until openSUSE 11.1.
* Mon Aug 24 2009 dimstar@opensuse.org
- Add compiz-fusion-plugins-main-bnc511578.patch (bnc#511578,
  upstream http://bugs.opencompositing.org/show_bug.cgi?id=1199).
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of removing static libraries
* Mon Feb  2 2009 davidr@novell.com
- Fix a number of issues to make animation plugin work
  better with non top-level windows and remote desktops.
  (bnc#471559)
* Fri Jan 30 2009 davidr@novell.com
- Enable wobbly support in expo plugin again as compiz core
  now includes the appropriate fix. (bnc#470020)
* Wed Jan 28 2009 davidr@novell.com
- Disable wobbly support in expo plugin. (bnc#470020)
* Tue Jan 27 2009 davidr@novell.com
- Add super keys as extra main menu keys in workaround
  plugin. (bnc#358713)
* Mon Jan 26 2009 davidr@novell.com
- Use walkDepthFirst function. (bnc#468433)
* Tue Nov 18 2008 davidr@novell.com
- Update NOMAD patch to track changes to NOMAD patch
  for compiz core.
* Mon Nov 17 2008 davidr@novell.com
- Add fixes for non top-level window support in neg,
  staticswitcher, shift, ring, thumbnail, animation,
  colorfilter plugins to NOMAD patch.
- Add fix for opacity plugin crash to NOMAD patch.
- Add fix related to use of unhookWindowFromScreen in
  staticswitcher plugin to NOMAD patch.
- Add fixes for staticswitcher, shift, ring plugin clipping
  issues to NOMAD patch.
* Mon Oct 13 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Sun Oct 12 2008 cyberorg@opensuse.org
- compiz-fusion-plugins-main-defaults.patch (bnc#434249)
* Wed Oct  8 2008 rodrigo@novell.com
- NOMAD updates from David Reveman (bnc#432313)
* Wed Oct  8 2008 rodrigo@novell.com
- NOMAD updates from David Reveman (bnc#432313)
* Mon Sep 29 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Mon Sep 22 2008 cyberorg@opensuse.org
- Performance improvements on all animations
* Wed Sep 17 2008 cyberorg@opensuse.org
- Release 0.7.8
- Fix constant damage of thumbnail while it is shown
- Animation plugin restructured
- Reorder groups and subgroups in metadata
- l10n updates
* Tue Jul  1 2008 mhopf@suse.de
- Update from buildservice.
* Sat May 31 2008 cyberorg@opensuse.org
- update to version 0.7.6
  - New plugin: Static Switcher, a simpler switcher with a moving
    caret instead of moving thumbnails
  - Ezoom: New Zoom Box action allows using the mouse to select a
    zoom region.
* Mon Apr 14 2008 mhopf@suse.de
- Update from buildservice.
* Thu Apr  3 2008 cyberorg@cyberorg.info
- 0.7.4 release
- Fix high cpu usage during expo mode
- Bring back inactive viewport saturation/brightness on exit
- Fixed expo reflection for vsize > 1
- Fix artifacts in Rollup animation
* Fri Mar  7 2008 cyberorg@opensuse.org
- 0.7.2 development release
- session: Communicates with session manager to save/restore window state
- bs: Change window brightness and saturation with key/button bindings
- mousepoll: Provides a generic system for other plugins to get the current
  mouse position
- mag: Provides a magnifying glass under the mouse pointer with 3 different
  display modes (simple/image overlay/fisheye)
* Fri Feb  8 2008 cyberorg@cyberorg.info
- sync to latest git
- BS brightness saturation plugin is back
- some animation plugin fixes
- new plugin mousepoll
* Tue Dec  4 2007 cyberorg@cyberorg.info
- sync to latest git
* Tue Oct 16 2007 cyberorg@cyberorg.info
- Update to release 0.6.0
* Thu Sep  6 2007 cyberorg@cyberorg.info
- Add compiz-fusion-vpswitch-initiate-fix.diff
* Fri Aug 24 2007 cyberorg@cyberorg.info
- Sync to the latest git.
- new action settings rework
- Shift animation improvement
* Wed Aug 22 2007 cyberorg@cyberorg.info
- Add %%post and %%postun to run ldconfig- shut rpmlint up
* Mon Aug 13 2007 cyberorg@cyberorg.info
- Update to 0.5.2 release.
- Some animation default changes.
- Fix gnome 2.19.X shutdown dialog & dimming layer handling.
- Switcher bug fixes
- Fix build for SLE
* Wed Aug  8 2007 schwab@suse.de
- Fix specfile.
* Mon Aug  6 2007 dreveman@suse.de
- Initial version of package
